km3pipe.calib.Calibration
=========================

.. currentmodule:: km3pipe.calib

.. autoclass:: Calibration

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Calibration.__init__
      ~Calibration.add
      ~Calibration.apply
      ~Calibration.apply_t0
      ~Calibration.configure
      ~Calibration.expose
      ~Calibration.finish
      ~Calibration.get
      ~Calibration.get_detector
      ~Calibration.pre_finish
      ~Calibration.process
      ~Calibration.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Calibration.name
   
   